@@ -3,6 +3,7 @@ from steam_nb_api.ledet.ParametersLEDET import ParametersLEDET
 import pandas as pd
 from steam_nb_api.ledet.Simulation import RunSimulations
 from steam_nb_api.ledet.SimulationEvaluation import EvaluateSimulations
+from steam_nb_api.ledet.SimulationEvaluation import QuenchPlanAnalysis
 from steam_nb_api.ledet.AutomaticSweep import AutomaticSweep
 import time
 
@@ -150,6 +151,11 @@ def testvQ():
     Sw.prepareSimulation(nameMagnet, "C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\D2",
                          ROXIE_File="C:\cernbox\SWAN_projects\steam-notebooks\steam-ledet-input\D2\D2_All_WithIron_WithSelfField.map2d")
 
+def testQuenchPlanAnalysis(FileName_TDMS, FileName_Sim):
+    a = QuenchPlanAnalysis(FileName_TDMS, FileName_Sim)
+    a.QuenchPlanAnalysis()
+    return a
+
 # testConsistencyChecks()
 # test_readLEDETExcel()
 # test_setgetAttributes()
@@ -158,7 +164,10 @@ def testvQ():
 # test_EvaluateSimulations()
 
 # CompleteRun()
-testvQ()
+
+td_data = "C:\\cernbox\\MasterThesis\\Measurement_data\MQXFS4b\\HCMQXSM001-CR000042__H1810111001_a001(0).tdms"
+sim_data = "C:\\cernbox\\LEDET_MT\\LEDET\\MQXFS4b\\Output\\Mat Files\\SimulationResults_LEDET_5.mat"
+a = testQuenchPlanAnalysis(td_data, sim_data)
 
 # a = ParametersLEDET()
 # a.readLEDETExcel(testfile7)
