@@ -6,6 +6,7 @@ from tqdm import tqdm
 from matplotlib import cm
 from mpl_toolkits.mplot3d import Axes3D
 import matplotlib.cm as cm
+import matplotlib.pylab as pl
 from matplotlib.collections import PolyCollection
 import matplotlib.pyplot as plt
 from matplotlib import colors as mcolors
@@ -13,6 +14,35 @@ import h5py
 from steam_nb_api.ledet.ParameterSweep import *
 from steam_nb_api.ledet.ParametersLEDET import ParametersLEDET
 import csv
+import nptdms
+from nptdms import TdmsFile
+
+
+@dataclass
+class TDMSdata:
+    FileName: str = ''
+    Tolerance: float = 20.0
+    groupHF:  nptdms.GroupObject = nptdms.GroupObject('HF')
+    groupMF: nptdms.GroupObject = nptdms.GroupObject('MF')
+    TimeFrame_MF: np.ndarray = np.array([])
+    t_steps_MF:  float = 0.0
+    t_d_MF: float = 0.0
+    trigger_PC: int = 0
+    I_DCCT_MF: np.ndarray = np.array([])
+    I_DCCT_HF: np.ndarray = np.array([])
+    QL1: float = 0.0
+    QL2: float = 0.0
+
+@dataclass
+class SIMdata:
+    FileName: str = ''
+    TimeFrame: np.ndarray = np.array([])
+    trigger_PC: int = 0
+    I_CoilSections: np.ndarray = np.array([])
+    I_CLIQ: np.ndarray = np.array([])
+    directionsCLIQ: np.ndarray = np.array([])
+    QL1: float = 0.0
+    QL2: float = 0.0
 
 def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True, Plots = True, SkipAlign = False, SetdITol = 200, showBestFit = 10):
     print("Reading Data and evaluate")
@@ -365,3 +395,129 @@ def EvaluateSimulations(MatFolder, MagnetName, MeasFile, SweepObject, Mat = True
         ax.set_ylabel(ParametersToSweep[Order[1]], fontsize =11)
         ax.set_zlabel(ParametersToSweep[Order[2]], fontsize =11)
         plt.show()
+
+class QuenchPlanAnalysis():
+    def __init__(self,FileNameTDMS, FileNameSIMData):
+        self.beforePC = 0.1
+        self.Colors = self.__generateColors()
+
+        self.SIMdata = SIMdata()
+        self.SIMdata.FileName = FileNameSIMData
+        self.__CreateSIMDataObject()
+
+        self.TDMSdata = TDMSdata()
+        self.TDMSdata.FileName = FileNameTDMS
+        self.__CreateTDMSDataObject()
+
+        self.__calculateAllQuenchIntegrals()
+
+    def __generateColors(self):
+        # n = 15
+        # colors = pl.cm.jet(np.linspace(0,1,n))
+        # setting colors for plotting
+        col = mcolors.TABLEAU_COLORS.keys()
+        col2 = mcolors.BASE_COLORS.keys()
+        col3 = mcolors.CSS4_COLORS.keys()
+        colors = []
+        for c in col:
+            colors = colors + [c]
+        for c in col2:
+            if c == 'w': continue
+            colors = colors + [c]
+        for c in col3:
+            if c == 'white': continue
+            if c == 'snow': continue
+            colors = colors + [c]
+        return colors
+
+    def __CreateTDMSDataObject(self):
+        tdms_file = TdmsFile.read(self.TDMSdata.FileName)
+        ## Save groups
+        for group in tdms_file.groups():
+            if group.name == 'HF': self.TDMSdata.groupHF = tdms_file['HF']
+            elif group.name == 'MF': self.TDMSdata.groupMF = tdms_file['MF']
+            else: print("Don't understand group: ", group)
+
+        ## Pick channels and store conveniently
+        for channel in self.TDMSdata.groupHF.channels():
+            if channel.name == 'IDCCT_HF': self.TDMSdata.I_DCCT_HF = channel.data
+        for channel in self.TDMSdata.groupMF.channels():
+            if channel.name == 'IDCCT_HF':
+                self.TDMSdata.I_DCCT_MF = channel.data*1000
+                self.TDMSdata.t_steps_MF = channel.properties['wf_samples']
+                self.TDMSdata.t_d_MF = channel.properties['wf_increment']
+            if channel.name == 'Trigger_PC':
+                trigger_data = channel.data
+        ## Set up Timeframe
+        self.TDMSdata.TimeFrame_MF = np.linspace(0,self.TDMSdata.t_steps_MF*self.TDMSdata.t_d_MF, int(self.TDMSdata.t_steps_MF))
+        trigger_shoot = np.gradient(trigger_data, self.TDMSdata.t_d_MF)
+        trigger_shoot = np.where(abs(trigger_shoot)>self.TDMSdata.Tolerance)[0][0]-int(self.beforePC/self.TDMSdata.t_d_MF)
+        self.TDMSdata.trigger_PC = int(self.beforePC/self.TDMSdata.t_d_MF)
+        self.TDMSdata.TimeFrame_MF = self.TDMSdata.TimeFrame_MF[trigger_shoot:]-self.TDMSdata.TimeFrame_MF[trigger_shoot]
+        self.TDMSdata.I_DCCT_MF = self.TDMSdata.I_DCCT_MF[trigger_shoot:]
+        return
+
+    def __CreateSIMDataObject(self):
+        if self.SIMdata.FileName.endswith('.mat'):
+            file = self.SIMdata.FileName
+            f = h5py.File(file, 'r')
+            self.SIMdata.TimeFrame = np.array(f.get("time_vector"))
+            self.SIMdata.I_CoilSections = np.array(f.get("I_CoilSections")).transpose()
+            self.SIMdata.I_CLIQ = np.array(f.get("Ic")).transpose()
+            trigger = np.array(f.get("t_PC"))[0][0]-self.beforePC
+            if trigger < float(self.SIMdata.TimeFrame[0]):
+                self.beforePC = -1* self.SIMdata.TimeFrame[0]
+                trigger = np.array(f.get("t_PC"))[0][0] - self.beforePC
+                print("Switch aligning to tStart of Simulation!")
+            trigger_shoot = np.where(abs(self.SIMdata.TimeFrame-trigger)<1E-4)[0][0]
+            self.SIMdata.trigger_PC = np.where(abs(self.SIMdata.TimeFrame-np.array(f.get("t_PC"))[0][0])<1E-4)[0][0]
+            self.SIMdata.TimeFrame = self.SIMdata.TimeFrame[trigger_shoot:]-self.SIMdata.TimeFrame[trigger_shoot]
+            self.SIMdata.I_CoilSections = self.SIMdata.I_CoilSections[:, trigger_shoot:]
+            self.SIMdata.I_CLIQ = self.SIMdata.I_CLIQ[trigger_shoot:]
+            self.SIMdata.directionsCLIQ = np.array(f.get("directionCurrentCLIQ"))
+        else:
+            print("Please provide .mat file for Simulation.")
+
+    def __calculateQuenchIntegral(self, time, current):
+        dt = np.gradient(time)
+        QL  = np.sum(np.multiply(dt, np.power(current,2)))/1E6
+        return QL
+
+    def __calculateAllQuenchIntegrals(self):
+        ## QL Integral 1 - full transient
+        ## QL Measured Data
+        self.TDMSdata.QL1 = self.__calculateQuenchIntegral(self.TDMSdata.TimeFrame_MF[self.TDMSdata.trigger_PC:], self.TDMSdata.I_DCCT_MF[self.TDMSdata.trigger_PC:])
+        ## QL Sim Data
+        if abs(sum(self.SIMdata.I_CLIQ))>0:
+            idxC = np.where(self.SIMdata.directionsCLIQ > 0)[0][0]
+            self.SIMdata.QL1 = self.__calculateQuenchIntegral(self.SIMdata.TimeFrame[self.SIMdata.trigger_PC:,0], self.SIMdata.I_CoilSections[self.SIMdata.trigger_PC:,idxC])
+        else:
+            print("IUhm")
+            self.SIMdata.QL1 = self.__calculateQuenchIntegral(self.SIMdata.TimeFrame[self.SIMdata.trigger_PC:,0], self.SIMdata.I_CoilSections[self.SIMdata.trigger_PC:,0])
+
+        ## QL Integral 2
+        ## tbd
+
+    def QuenchPlanAnalysis(self, Plot = 0):
+        # Plot current together
+        if Plot:
+            fig = plt.figure()
+            ax = fig.add_subplot(111)
+            legend = []
+            for i in range(self.SIMdata.I_CoilSections.shape[1]):
+                legend.append("$I_{Sim, CoilSection " + str(i+1) + "}$")
+                ax.plot(self.SIMdata.TimeFrame, self.SIMdata.I_CoilSections[:,i], color= self.Colors[i])
+            if sum(self.SIMdata.I_CLIQ) != 0:
+                ax.plot(self.SIMdata.TimeFrame, self.SIMdata.I_CLIQ, color= self.Colors[self.SIMdata.I_CoilSections.shape[1]+1])
+                legend.append("$I_{CLIQ}$")
+            ax.plot(self.TDMSdata.TimeFrame_MF, self.TDMSdata.I_DCCT_MF, color= self.Colors[self.SIMdata.I_CoilSections.shape[1]+2])
+            legend.append("$I_{Meas}$")
+            ax.grid(True)
+            ax.set_ylabel("Current [A]", fontsize=20)
+            ax.set_xlabel("Time [s]", fontsize=20)
+            ax.set_ylim([np.amin([np.amin(self.SIMdata.I_CoilSections),np.amin(self.SIMdata.I_CLIQ), np.amin(self.TDMSdata.I_DCCT_MF)])*1.1,
+                         np.amax([np.amax(self.SIMdata.I_CoilSections),np.amax(self.SIMdata.I_CLIQ), np.amax(self.TDMSdata.I_DCCT_MF)])*1.1])
+            ax.set_xlim([0, np.amax([np.amax(self.TDMSdata.TimeFrame_MF), np.amax(self.SIMdata.TimeFrame)])])
+            ax.legend(legend,fontsize=20)
+            # ax.set_title("Currents ")
+        return [self.TDMSdata, self.SIMdata]
\ No newline at end of file
